#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 input-parsers
version:              0.3.0.2
visibility:           public
id:                   input-parsers-0.3.0.2-8EKBkL58OfS7fqN4FbbIox
key:                  input-parsers-0.3.0.2-8EKBkL58OfS7fqN4FbbIox
license:              BSD-3-Clause
copyright:            (c) 2020 Mario Blažević
maintainer:           blamario@protonmail.com
author:               Mario Blažević
synopsis:
    Extension of the parsers library with more capability and efficiency

description:
    Extended version of the parsers library, with the additional classes providing more
    capable and efficient methods.

category:             Parsing
abi:                  4fd89ae119cac56015a113af7265c655
exposed:              True
exposed-modules:
    Text.Parser.Deterministic Text.Parser.Input
    Text.Parser.Input.Position Text.Parser.Wrapper

hidden-modules:       Text.Parser.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/input-parsers-0.3.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/input-parsers-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/input-parsers-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-input-parsers
hs-libraries:         HSinput-parsers-0.3.0.2-8EKBkL58OfS7fqN4FbbIox
depends:
    attoparsec-0.14.4-3CmiIm11iun2BHKDR4ovn7 base-4.18.2.1
    binary-0.8.9.1 bytestring-0.11.5.3
    monoid-subclasses-1.2.6.1-4UErjkVzo1AJYX7u0WDOEq parsec-3.1.16.1
    parsers-0.12.12-8SQd30A0FjtFXEkvloMdas text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-input-parsers/html/input-parsers.haddock

haddock-html:         /usr/share/doc/haskell-input-parsers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

